# FC5 and later include SELinux policy module packages
%if 0%{?fedora} < 5
%define selinux_module 0
%define selinux_variants %{nil}
%else
%define selinux_module 1
%define selinux_variants mls strict targeted
%endif

Name:           mod_fcgid
Version:        1.10
Release:        2%{?dist}
Summary:        Apache2 module for high-performance server-side scripting 
Group:          System Environment/Daemons
License:        GPL
URL:            http://fastcgi.coremail.cn/
Source0:        http://fastcgi.coremail.cn/mod_fcgid.%{version}.tar.gz
Source1:        fcgid.conf
Source2:        fastcgi.te
Source3:        fastcgi.fc
Source4:        README.Fedora
Source5:        http://fastcgi.coremail.cn/doc.htm
Source6:        http://fastcgi.coremail.cn/configuration.htm
Patch0:         mod_fcgid.1.09-docurls.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  httpd-devel >= 2.0 
Requires:       httpd-mmn = %([ -a %{_includedir}/httpd/.mmn ] && %{__cat} %{_includedir}/httpd/.mmn || echo missing)
%if %{selinux_module}
# selinux-policy >= 2.2.40 needed because of #190561
BuildRequires:  checkpolicy, selinux-policy >= 2.2.40, m4
# hack to avoid problems mixing new modules with older policy, e.g.
# http://www.redhat.com/archives/fedora-selinux-list/2006-May/msg00102.html
# Ideally this will be replaced by an ABI version requirement or something similar
%define selinux_policyver %(sed -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp)
%if "%{selinux_policyver}" != ""
Conflicts:      selinux-policy < %{selinux_policyver}
%endif
%endif

%description
mod_fcgid is a binary-compatible alternative to the Apache module mod_fastcgi.
mod_fcgid has a new process management strategy, which concentrates on reducing
the number of fastcgi servers, and kicking out corrupt fastcgi servers as soon
as possible.

%prep
%setup -q -n mod_fcgid.%{version}
%{__cp} -p %{SOURCE2} %{SOURCE3} %{SOURCE4} %{SOURCE6} .
%{__cp} -p %{SOURCE5} directives.htm
%patch0 -p1
%{__sed} -i -e 's/\r$//' directives.htm configuration.htm

%build
%{__make} top_dir=%{_sysconfdir}/httpd
%if %{selinux_module}
for selinuxvariant in %{selinux_variants}
do
    %{__make} NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
    %{__mv} fastcgi.pp fastcgi.pp.${selinuxvariant}
    %{__make} NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done
%endif

%install
%{__rm} -rf %{buildroot}
%{__make} \
        top_dir=%{_sysconfdir}/httpd \
        DESTDIR=%{buildroot} \
        MKINSTALLDIRS="%{__mkdir_p}" \
        install
%{__install} -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/httpd/conf.d/fcgid.conf
%{__install} -d -m 755 %{buildroot}%{_localstatedir}/run/mod_fcgid

# Install SELinux policy modules
%if %{selinux_module}
for selinuxvariant in %{selinux_variants}
do
    %{__install} -d %{buildroot}%{_datadir}/selinux/packages/${selinuxvariant}
    %{__install} -p -m 644 fastcgi.pp.${selinuxvariant} \
           %{buildroot}%{_datadir}/selinux/packages/${selinuxvariant}/fastcgi.pp
done
%endif

%clean
%{__rm} -rf %{buildroot}

%if %{selinux_module}
%post
# Install SELinux policy modules
if [ -x /usr/sbin/semodule ]; then
  for selinuxvariant in %{selinux_variants}
  do
    /usr/sbin/semodule -s ${selinuxvariant} -i \
      %{_datadir}/selinux/packages/${selinuxvariant}/fastcgi.pp &> /dev/null || :
  done
fi
# Fix up non-standard directory context
[ -x /sbin/restorecon ] && /sbin/restorecon %{_localstatedir}/run/mod_fcgid || :

%postun
# Clean up after package removal
if [ $1 -eq 0 ]; then
  # Remove SELinux policy modules
  if [ -x /usr/sbin/semodule ]; then
    for selinuxvariant in %{selinux_variants}
    do
      /usr/sbin/semodule -s ${selinuxvariant} -r fastcgi &> /dev/null || :
    done
  fi
  # Clean up any remaining file contexts (shouldn't be any really)
  [ -x /sbin/restorecon -a -d %{_localstatedir}/run/mod_fcgid ] && \
    /sbin/restorecon -R %{_localstatedir}/run/mod_fcgid &> /dev/null || :
fi
%endif

%files
%defattr(-,root,root,0755)
%doc ChangeLog AUTHOR COPYING configuration.htm directives.htm
%doc README.Fedora fastcgi.fc fastcgi.te
%{_libdir}/httpd/modules/mod_fcgid.so
%config(noreplace) %{_sysconfdir}/httpd/conf.d/fcgid.conf
%dir %attr(0755,apache,apache) %{_localstatedir}/run/mod_fcgid
%if %{selinux_module}
%dir %{_datadir}/selinux/packages
%dir %{_datadir}/selinux/packages/*
%{_datadir}/selinux/packages/*/fastcgi.pp
%endif

%changelog
* Wed Jul  5 2006 Paul Howarth <paul@city-fan.org> 1.10-2
- SELinux policy update: allow FastCGI apps to do DNS lookups

* Tue Jul  4 2006 Paul Howarth <paul@city-fan.org> 1.10-1
- Update to 1.10
- Expand tabs to shut rpmlint up

* Tue Jul  4 2006 Paul Howarth <paul@city-fan.org> 1.09-10
- SELinux policy update:
  * allow httpd to read httpd_fastcgi_content_t without having the
    httpd_builtin_scripting boolean set
  * allow httpd_fastcgi_script_t to read /etc/resolv.conf without
    having the httpd_can_network_connect boolean set

* Sun Jun 18 2006 Paul Howarth <paul@city-fan.org> 1.09-9
- Discard output of semodule in %%postun
- Include some documentation from upstream

* Fri Jun  9 2006 Paul Howarth <paul@city-fan.org> 1.09-8
- Change default context type for socket directory from var_run_t to
  httpd_fastcgi_sock_t for better separation

* Thu Jun  8 2006 Paul Howarth <paul@city-fan.org> 1.09-7
- Add SELinux policy module and README.Fedora
- Conflict with selinux-policy versions older than what we're built on

* Mon May 15 2006 Paul Howarth <paul@city-fan.org> 1.09-6
- Instead of conflicting with mod_fastcgi, don't add the handler for .fcg etc.
  if mod_fastcgi is present

* Fri May 12 2006 Paul Howarth <paul@city-fan.org> 1.09-5
- Use correct handler name in fcgid.conf
- Conflict with mod_fastcgi
- Create directory %%{_localstatedir}/run/mod_fcgid for sockets

* Thu May 11 2006 Paul Howarth <paul@city-fan.org> 1.09-4
- Cosmetic tweaks (personal preferences)
- Don't include INSTALL.TXT, nothing of use to end users

* Wed May 10 2006 Thomas Antony <thomas@antony.eu> 1.09-3
- Initial release
